<?php

namespace Realestate\Place\Policies;

use Litepie\User\Contracts\UserPolicy;
use Realestate\Place\Models\City;

class CityPolicy
{

    /**
     * Determine if the given user can view the city.
     *
     * @param UserPolicy $user
     * @param City $city
     *
     * @return bool
     */
    public function view(UserPolicy $user, City $city)
    {
        if ($user->canDo('place.city.view') && $user->isAdmin()) {
            return true;
        }

        return $city->user_id == user_id() && $city->user_type == user_type();
    }

    /**
     * Determine if the given user can create a city.
     *
     * @param UserPolicy $user
     * @param City $city
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('place.city.create');
    }

    /**
     * Determine if the given user can update the given city.
     *
     * @param UserPolicy $user
     * @param City $city
     *
     * @return bool
     */
    public function update(UserPolicy $user, City $city)
    {
        if ($user->canDo('place.city.update') && $user->isAdmin()) {
            return true;
        }

        return $city->user_id == user_id() && $city->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given city.
     *
     * @param UserPolicy $user
     * @param City $city
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, City $city)
    {
        return $city->user_id == user_id() && $city->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given city.
     *
     * @param UserPolicy $user
     * @param City $city
     *
     * @return bool
     */
    public function verify(UserPolicy $user, City $city)
    {
        if ($user->canDo('place.city.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given city.
     *
     * @param UserPolicy $user
     * @param City $city
     *
     * @return bool
     */
    public function approve(UserPolicy $user, City $city)
    {
        if ($user->canDo('place.city.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
