<?php

namespace Realestate\Place\Providers;

use Illuminate\Support\ServiceProvider;

class PlaceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'place');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'place');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('realestate.place', function ($app) {
            return $this->app->make('Realestate\Place\Place');
        });

        // Bind District to repository
        $this->app->bind(
            'Realestate\Place\Interfaces\DistrictRepositoryInterface',
            \Realestate\Place\Repositories\Eloquent\DistrictRepository::class
        );
        // Bind City to repository
        $this->app->bind(
            'Realestate\Place\Interfaces\CityRepositoryInterface',
            \Realestate\Place\Repositories\Eloquent\CityRepository::class
        );

        $this->app->register(\Realestate\Place\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Realestate\Place\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['realestate.place'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('realestate/place.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/place')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/place')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
